raise Exception("""

    smart-insights is a commercial package distributed on
    instances of Dash Enterprise https://plotly.com/dash/.
    You have installed a non-functional stub version of the package
    from pypi.org instead of from a private Dash Enterprise instance.
    If you are a Dash Enterprise customer, please ensure you've
    installed smart-insights with the `--extra-index-url` argument,
    either in your requirements.txt file or in the command line,
    so that the package is installed from Dash Enterprise's private,
    commercial package repository instead of from pypi.org.
    Visit the docs for your Dash Enterprise installation at:
    https://<your-dash-enterprise-instance>/Docs
    for details.

""")



from setuptools import setup

with open('README.md') as f:
    readme = f.read()

setup(
    name="smart-insights",
    version="0.0.1",
    author="Alex Johnson",
    author_email="alex@plotly.com",
    url="https://plotly.com/dash/",
    packages=["smart_insights"],
    license="Commercial",
    description="A public stub for smart-insights by Plotly",
    long_description=readme,
    long_description_content_type='text/markdown',
    install_requires=[],
    classifiers=[
        "Programming Language :: Python :: 3",
        "Framework :: Dash",
    ],
)
